@@ -1,5 +1,5 @@
 package Test::Selenium::Remote::Driver;
-$Test::Selenium::Remote::Driver::VERSION = '0.23';
+$Test::Selenium::Remote::Driver::VERSION = '0.24';
 # ABSTRACT: Useful testing subclass for Selenium::Remote::Driver
 
 use Moo;
@@ -258,7 +258,7 @@ sub _find_element_with_action {
             if (!defined($self->FINDERS->{$locator_strategy})) { 
                 $desc = $params; 
                 $params = $locator_strategy; 
-                $locator_strategy = $self->default_finder;
+                $locator_strategy = $self->_get_finder_key($self->default_finder);
             }
         }
         else { 
@@ -266,7 +266,7 @@ sub _find_element_with_action {
             if ($locator_strategy) { 
                 if (!defined($self->FINDERS->{$locator_strategy})) { 
                     $params = $locator_strategy; 
-                    $locator_strategy = $self->default_finder;
+                    $locator_strategy = $self->_get_finder_key($self->default_finder);
                 }
             }
             else { 
